@@ -27,7 +27,7 @@ public:
 	
 	int findPeriod() const;
 	
-	QString exportUnit() const;
+	QString exportUnit() const Q_DECL_OVERRIDE;
 };
 
 #endif // CTHOUR_H
